@@ -36,8 +36,8 @@ class EngineManager:
         for name in list(dict.keys(self.engines)):
             engine = self.engines.pop(name)
             result = engine.dispose()
-            if inspect.iscoroutine(result):
-                loop.create_task(result)
+            if inspect.iscoroutine(result) and loop.is_running():
+                loop.run_until_complete(result)
 
     def __len__(self):
         return len(self.engines)
